@@ -12,11 +12,7 @@ __PACKAGE__->has_a(
 	inflate => sub { Date::Simple->new(shift) },
 	deflate => 'format',
 );
-
-sub _column_placeholder {
-	my ($self, $column) = @_;
-	return $column eq "tdate" ? "IF(1, CURDATE(), ?)" : "?";
-}
+__PACKAGE__->find_column('tdate')->placeholder("IF(1, CURDATE(), ?)");
 
 sub create_sql {
 	return qq{
